<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="197"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation type="unfinished">Oppsett av egendefinert kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation type="unfinished">Visning</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use icon from theme or browse file</source>
        <translation type="unfinished">Bruk ikon fra drakt eller velg fil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation type="unfinished">Kjør med «bash -c»</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>Velg skrift</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="72"/>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>Skrift</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source> px</source>
        <translation> piksler</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source>Use %1 to display command output</source>
        <translation type="unfinished">Bruk %1 for å vise kommando-resultat</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="201"/>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Browse</source>
        <translation>Utforsk</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Autoroter når panelet er loddrett</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="94"/>
        <source>echo Configure...</source>
        <translation>echo Oppsett…</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="308"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="342"/>
        <source>Command to run</source>
        <translation>Kommando å kjøre</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="258"/>
        <source>Max Width</source>
        <translation>Maksimal bredde</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="156"/>
        <source>Repeat command after:</source>
        <translation>Gjenta kommando etter:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Text Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="62"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="172"/>
        <source> second(s)</source>
        <translation> sekund(er)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="194"/>
        <source>Command outputs an image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source>Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Mouse Commands</source>
        <translation>Musekommandoer</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="298"/>
        <source>Click</source>
        <translation>Klikk</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="315"/>
        <source>Wheel Up</source>
        <translation type="unfinished">Musehjul opp</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="332"/>
        <source>Wheel Down</source>
        <translation type="unfinished">Musehjul ned</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Select Icon File</source>
        <translation>Velg ikonfil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Bilder (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
